summaryrefslogtreecommitdiff
path: root/src/modules/extra/m_ssl_mbedtls.cpp
diff options
context:
space:
mode:
authorMatt Schatz <genius3000@g3k.solutions>2020-04-12 22:56:10 -0600
committerMatt Schatz <genius3000@g3k.solutions>2020-04-14 06:08:31 -0600
commitccebfe6e637b420bef05e8e0faf29bb19f1883d9 (patch)
tree7c2a3220343f7f4dd34eaf60bf77f5f1bda20638 /src/modules/extra/m_ssl_mbedtls.cpp
parentc506023c5a0ba9abac4dad2d75115f71885dfc2f (diff)
Update user-facing text and comments of SSL to TLS.
Diffstat (limited to 'src/modules/extra/m_ssl_mbedtls.cpp')
-rw-r--r--src/modules/extra/m_ssl_mbedtls.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/modules/extra/m_ssl_mbedtls.cpp b/src/modules/extra/m_ssl_mbedtls.cpp
index dded7e171..628230d29 100644
--- a/src/modules/extra/m_ssl_mbedtls.cpp
+++ b/src/modules/extra/m_ssl_mbedtls.cpp
@@ -586,7 +586,7 @@ class mbedTLSIOHook : public SSLIOHook
}
CloseSession();
- sock->SetError("No SSL session");
+ sock->SetError("No TLS (SSL) session");
return -1;
}
@@ -865,7 +865,7 @@ class ModuleSSLmbedTLS : public Module
{
// First, store all profiles in a new, temporary container. If no problems occur, swap the two
// containers; this way if something goes wrong we can go back and continue using the current profiles,
// avoiding unpleasant situations where no new SSL connections are possible.
ProfileList newprofiles;
ConfigTagList tags = ServerInstance->Config->ConfTags("sslprofile");
@@ -883,7 +883,7 @@ class ModuleSSLmbedTLS : public Module
}
catch (CoreException& ex)
{
- throw ModuleException("Error while initializing the default SSL profile - " + ex.GetReason());
+ throw ModuleException("Error while initializing the default TLS (SSL) profile - " + ex.GetReason());
}
}
@@ -908,7 +908,7 @@ class ModuleSSLmbedTLS : public Module
}
catch (CoreException& ex)
{
- throw ModuleException("Error while initializing SSL profile \"" + name + "\" at " + tag->getTagLocation() + " - " + ex.GetReason());
+ throw ModuleException("Error while initializing TLS (SSL) profile \"" + name + "\" at " + tag->getTagLocation() + " - " + ex.GetReason());
}
newprofiles.push_back(prov);
@@ -945,7 +945,7 @@ class ModuleSSLmbedTLS : public Module
try
{
ReadProfiles();
- ServerInstance->SNO->WriteToSnoMask('a', "SSL module %s rehashed.", MODNAME);
+ ServerInstance->SNO->WriteToSnoMask('a', "TLS (SSL) module mbedTLS rehashed.");
}
catch (ModuleException& ex)
{
@@ -961,9 +961,9 @@ class ModuleSSLmbedTLS : public Module
LocalUser* user = IS_LOCAL(static_cast<User*>(item));
if ((user) && (user->eh.GetModHook(this)))
{
- // User is using SSL, they're a local user, and they're using our IOHook.
- // Potentially there could be multiple SSL modules loaded at once on different ports.
- ServerInstance->Users.QuitUser(user, "SSL module unloading");
+ // User is using TLS (SSL), they're a local user, and they're using our IOHook.
+ // Potentially there could be multiple TLS (SSL) modules loaded at once on different ports.
+ ServerInstance->Users.QuitUser(user, "mbedTLS module unloading");
}
}
@@ -865,7 +865,7 @@ class ModuleSSLmbedTLS : public Module
// First, store all profiles in a new, temporary container. If no problems occur, swap the two
// containers; this way if something goes wrong we can go back and continue using the current profiles,
- // avoiding unpleasant situations where no new SSL connections are possible.
+ // avoiding unpleasant situations where no new TLS (SSL) connections are possible.
ProfileList newprofiles;
ConfigTagList tags = ServerInstance->Config->ConfTags("sslprofile");